#
# spec file for package flashfocus
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flashfocus
Version:        2.4.1
Release:        1.5
Summary:        Focus animations for tiling window managers
License:        MIT
Group:          System/X11/Utilities
URL:            https://github.com/fennerm/flashfocus
Source:         https://github.com/fennerm/flashfocus/archive/v%{version}.tar.gz
Patch0:         flashfocus-2.4.0-no-i3ipc.patch
BuildRequires:  fdupes
BuildRequires:  libffi-devel
BuildRequires:  libxcb-devel
BuildRequires:  python3 >= 3.8
BuildRequires:  python3-pip
BuildRequires:  python3-pip-wheel
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
Requires:       python3-PyYAML >= 5.1
Requires:       python3-cffi
Requires:       python3-click
Requires:       python3-marshmallow
Requires:       python3-xcffib
Requires:       python3-xpybutil
Recommends:     compton
BuildArch:      noarch

%description
Focus animations for tiling window managers. Compatible with all X based window managers.

%prep
%autosetup -p1
sed -i "s/#!\/usr\/bin\/env bash/#!\/bin\/bash/" bin/nc_flash_window

%build
%python3_pyproject_wheel

%install
%python3_pyproject_install
%fdupes -s %{buildroot}

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/flash_window
%{_bindir}/flashfocus
%{_bindir}/nc_flash_window
%{python3_sitelib}/flashfocus*

%changelog
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
- Use %%python3_pyproject_wheel instead of %%pyproject_wheel
* Mon Sep 25 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.4.1:
  * Fixed: Error when .config/flashfocus exists but no config file present
  * Fixed: Multiple sigints required to terminate flashfocus on sway
  * Update to use ruff and pre-commit
  * Modernize type hints
* Mon Sep 25 2023 Michael Vetter <mvetter@suse.com>
- Update to 2.4.0:
  * Updated: Drop support for python 3.6 and 3.7
  * Updated: PEP 517 build system
- Remove flashfocus-2.0.3-no-i3ipc.patch
- Add flashfocus-2.4.0-no-i3ipc.patch
* Mon Oct 24 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.3.1:
  * Fixed: #78 Fix error when the current workspace is null
  * Not user facing: #79 Fixed a bunch of mypy warnings
* Tue Sep 13 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.3.0:
  * Added: #74 pyproject.toml config
  * Fixed: #77 Rare race condition when detecting the current workspace
  * Fixed: #78 Traceback when the current workspace is null
  * Not user facing:
    + #74 Misc. code cleanup/ linter fixes
    + #75 Fix bug in Dockerfile
    + #77 Add github action for running tests and fix some flakey tests
    + #76 Add CODEOWNERS file
* Mon Jul 11 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.2.5:
  * Fixed: Relax PyYaml dependency
* Fri Dec 10 2021 pgajdos@suse.com
- pytest-runner is deprecated
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.2.4:
  * Fixed: Remove pytest from setup.py requirements (as it is not really required).
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.2.3:
  * Bump click dependency to v9
* Mon Aug 10 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.2.2:
  * Added: #55 Emit warning when flash-fullscreen: true in sway.
* Mon Jul  6 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.2.1:
  * Fixed: Renamed (--loglevel/-l) param to (--verbosity/-v) due
    to conflict with --flash-lone-windows
* Mon Jun  1 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.2.0:
  * Added: --loglevel CLI option
  * Fixed: Removed --opacity documentation in help
* Tue Mar 31 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.1.3:
  * Fixed: #46 Accidental bump of required version of i3ipc
- Refresh flashfocus-2.0.3-no-i3ipc.patch
* Mon Mar  9 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.1.2:
  * (Hopefully) fixed: #43 - Error when setting rules in config
  * Add support for Click 7.0
* Mon Sep 30 2019 mvetter@suse.com
- Update to 2.1.1:
  * Fixed: #39 Crashes when switching tags on dwm
  * Handle null NET_WM_STATE when detecting fullscreen
- Changes from 2.1.0:
  * Added: flash-fullscreen/no-flash-fullscreen config options
  * Fixed: Exit without traceback for non-supported wayland WMs
  * Fixed: Cleaned up flakey tests
* Sun Sep 15 2019 mvetter@suse.com
- Update to 2.0.5:
  * Add support for marshmallow v3
- Does not work with i3/sway yet because we don't have i3ipc
  packaged
* Tue Sep 10 2019 mvetter@suse.com
- Update to 2.0.3:
  * Fix typo in marshmallow pin
  * Add init.py to display_protocols submodule
- Add flashfocus-2.0.3-no-i3ipc.patch
* Mon Sep  9 2019 mvetter@suse.com
- Update to 2.0.1:
  * Temporarily pin marshmallow to v2
  * Added sway support
  * Dropped python2 support
  * Increased minimum pyyaml version to 5.1
  * Added i3ipc requirement
* Tue May 28 2019 mvetter@suse.com
- Update to 1.2.7:
  * Added support for marshmallow v3 which is in prerelease
  * Set windows to default opacity even if they're not flashed (#25)
* Mon May 27 2019 mvetter@suse.com
- Update to 1.2.5:
  * Stopped using the deprecated inspect.getargspec API in python3
  * Bug fix (issue #25)
* Wed Jan 30 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Fix build with python 3.7
* Mon Jan 28 2019 mvetter@suse.com
- Update to 1.2.1:
  * Reverted Pyyaml requirement to >3.0
* Tue Jan 22 2019 mvetter@suse.com
- Update to 1.2.0:
  * Added flash-lone-windows CLI option.
  * Added: ability to set custom config file location with --config flag
  * Fixed: Use marshmallow strict mode due to deprecation warning
  * Fixed: Updated pyaml version in requirements due to security vulnerability
* Mon Oct 15 2018 mvetter@suse.com
- Update to 1.1.1:
  * Implemented flash-lone-windows configuration option
    (see default config file for details)
  * Added flash-lone-windows CLI option
* Thu Sep  6 2018 mvetter@suse.com
- Update to 1.0.9:
  * Improved test suite runtime
  * Fix uncaught AttributeError when RuleMatcher returns None
  * Fix bug which broke window flashing with transparent windows(#18)
  * Code refactoring
* Thu Jun  7 2018 mvetter@suse.com
- Fix /bin/bash path
* Wed Jun  6 2018 mvetter@suse.com
- Only replace env in nc_flash_window via sed
* Wed Jun  6 2018 mvetter@suse.com
- Recommend compton
* Wed Jun  6 2018 mvetter@suse.com
- Initial package in version 1.0.7 for openSUSE
